@@ -14,7 +14,7 @@
 #' 
 #' @seealso [stabilityClass()], [plotAvgRad()], [plotAvgTemp()]
 #' 
-#' @importFrom scales percent
+#' @importFrom scales label_percent
 #' 
 #' @export
 #' @examples
@@ -71,7 +71,7 @@ plotStabilityClass <- function(mydata, sc="sc", type="season") {
             geom_bar(position = "fill")
     }
     v <- v + 
-        scale_y_continuous(labels = scales::percent, breaks = seq(0,1,0.1)) +
+        scale_y_continuous(labels = scales::label_percent(), breaks = seq(0,1,0.1)) +
         scale_fill_brewer(palette = "Spectral", direction = -1) + 
         labs(x = "", y = "Percentuale (%)") +
         theme_bw(base_family = "sans") +
