@@ -4,7 +4,7 @@ ap <- NULL
 
 .onLoad <- function(libname, pkgname) {
     # use super-assignment to update global reference to arinfopy
-    reticulate::use_python("python3")
+    # reticulate::use_python("python")
     ap <- reticulate::import("arinfopy", delay_load = TRUE)
     
     utils::globalVariables(c("level", "..level.."))
